summaryrefslogtreecommitdiff
path: root/framework/inc/threadhelp/writeguard.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'framework/inc/threadhelp/writeguard.hxx')
-rw-r--r--framework/inc/threadhelp/writeguard.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/inc/threadhelp/writeguard.hxx b/framework/inc/threadhelp/writeguard.hxx
index 696b4780ffa4..faf123086ca9 100644
--- a/framework/inc/threadhelp/writeguard.hxx
+++ b/framework/inc/threadhelp/writeguard.hxx
@@ -30,7 +30,7 @@ namespace framework{
@short implement a guard to set write locks
@descr This guard should be used to set a lock for reading AND writing object internal member.
We never need a own mutex to safe our internal member access - because
- a guard is used as function-local member only. There exist no multithreaded access to it realy ...
+ a guard is used as function-local member only. There exist no multithreaded access to it really ...
@attention a) To prevent us against wrong using, the default ctor, copy ctor and the =operator are maked private!
b) Use interface "IRWLock" of set LockHelper only - because we must support a finer granularity of locking.
@@ -144,7 +144,7 @@ class WriteGuard : private INonCopyable
{
case E_READLOCK : {
// User has downgraded to a read lock before!
// => There isn't realy a write lock ...
m_pLock->releaseReadAccess();
m_eMode = E_NOLOCK;
}
@@ -144,7 +144,7 @@ class WriteGuard : private INonCopyable
case E_READLOCK : {
// User has downgraded to a read lock before!
- // => There isn't realy a write lock ...
+ // => There isn't really a write lock ...
m_pLock->releaseReadAccess();
m_eMode = E_NOLOCK;